@@ -1,7 +1,5 @@
 ( cd opt/kde/share/doc/HTML/de/ark ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/ark ; ln -sf /opt/kde/share/doc/HTML/de/common common )
-( cd opt/kde/share/doc/HTML/de/faq ; rm -rf common )
-( cd opt/kde/share/doc/HTML/de/faq ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kdf ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kdf ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kdm ; rm -rf common )
@@ -18,6 +16,10 @@
 ( cd opt/kde/share/doc/HTML/de/amor ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/karm ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/karm ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/kate ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/kate ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/kdat ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/kdat ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kdvi ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kdvi ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kget ; rm -rf common )
@@ -64,6 +66,10 @@
 ( cd opt/kde/share/doc/HTML/de/ksysguard ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kbounce ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kbounce ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/kdelirc/kcmlirc ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/kdelirc/kcmlirc ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/kdelirc/irkick ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/kdelirc/irkick ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kbattleship ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kbattleship ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kaboodle ; rm -rf common )
@@ -142,12 +148,20 @@
 ( cd opt/kde/share/doc/HTML/de/klinkstatus ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kompare ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kompare ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/kompmgr ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/kompmgr ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/kontact ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/kontact ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/konsole ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/konsole ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/konsolekalendar ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/konsolekalendar ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kcachegrind ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kcachegrind ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kpackage ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kpackage ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/lilo-config ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/lilo-config ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/khelpcenter/faq ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/khelpcenter/faq ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/khelpcenter/quickstart ; rm -rf common )
@@ -166,6 +180,8 @@
 ( cd opt/kde/share/doc/HTML/de/ksirtet ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/konquest ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/konquest ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/akregator ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/akregator ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kspaceduel ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kspaceduel ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kturtle ; rm -rf common )
@@ -186,118 +202,12 @@
 ( cd opt/kde/share/doc/HTML/de/kmenuedit ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kioslave ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kioslave ; ln -sf /opt/kde/share/doc/HTML/de/common common )
-( cd opt/kde/share/doc/HTML/de/flashkard ; rm -rf common )
-( cd opt/kde/share/doc/HTML/de/flashkard ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kbackgammon ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kbackgammon ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/knetattach ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/knetattach ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kaddressbook ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kaddressbook ; ln -sf /opt/kde/share/doc/HTML/de/common common )
-( cd opt/kde/share/doc/HTML/de/glossary ; rm -rf common )
-( cd opt/kde/share/doc/HTML/de/glossary ; ln -sf /opt/kde/share/doc/HTML/de/common common )
-( cd opt/kde/share/doc/HTML/de/common ; rm -rf fdl-license )
-( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/fdl-license fdl-license )
-( cd opt/kde/share/doc/HTML/de/common ; rm -rf qpl-license.html )
-( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/qpl-license.html qpl-license.html )
-( cd opt/kde/share/doc/HTML/de/common ; rm -rf x11-license.html )
-( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/x11-license.html x11-license.html )
-( cd opt/kde/share/doc/HTML/de/common ; rm -rf 1.png )
-( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/1.png 1.png )
-( cd opt/kde/share/doc/HTML/de/common ; rm -rf xml.dcl )
-( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/xml.dcl xml.dcl )
-( cd opt/kde/share/doc/HTML/de/common ; rm -rf 2.png )
-( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/2.png 2.png )
-( cd opt/kde/share/doc/HTML/de/common ; rm -rf 3.png )
-( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/3.png 3.png )
-( cd opt/kde/share/doc/HTML/de/common ; rm -rf 4.png )
-( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/4.png 4.png )
-( cd opt/kde/share/doc/HTML/de/common ; rm -rf 5.png )
-( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/5.png 5.png )
-( cd opt/kde/share/doc/HTML/de/common ; rm -rf 6.png )
-( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/6.png 6.png )
-( cd opt/kde/share/doc/HTML/de/common ; rm -rf 7.png )
-( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/7.png 7.png )
-( cd opt/kde/share/doc/HTML/de/common ; rm -rf top-right-konqueror.png )
-( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/top-right-konqueror.png top-right-konqueror.png )
-( cd opt/kde/share/doc/HTML/de/common ; rm -rf 8.png )
-( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/8.png 8.png )
-( cd opt/kde/share/doc/HTML/de/common ; rm -rf 9.png )
-( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/9.png 9.png )
-( cd opt/kde/share/doc/HTML/de/common ; rm -rf headerbg.png )
-( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/headerbg.png headerbg.png )
-( cd opt/kde/share/doc/HTML/de/common ; rm -rf gpl-license.html )
-( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/gpl-license.html gpl-license.html )
-( cd opt/kde/share/doc/HTML/de/common ; rm -rf mainheader.html )
-( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/mainheader.html mainheader.html )
-( cd opt/kde/share/doc/HTML/de/common ; rm -rf grad.png )
-( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/grad.png grad.png )
-( cd opt/kde/share/doc/HTML/de/common ; rm -rf kde-web.css )
-( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/kde-web.css kde-web.css )
-( cd opt/kde/share/doc/HTML/de/common ; rm -rf kde_logo_bg.png )
-( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/kde_logo_bg.png kde_logo_bg.png )
-( cd opt/kde/share/doc/HTML/de/common ; rm -rf lgpl-license.html )
-( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/lgpl-license.html lgpl-license.html )
-( cd opt/kde/share/doc/HTML/de/common ; rm -rf doxygen.css )
-( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/doxygen.css doxygen.css )
-( cd opt/kde/share/doc/HTML/de/common ; rm -rf web-doctop.png )
-( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/web-doctop.png web-doctop.png )
-( cd opt/kde/share/doc/HTML/de/common ; rm -rf kde-default.css )
-( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/kde-default.css kde-default.css )
-( cd opt/kde/share/doc/HTML/de/common ; rm -rf kmenu.png )
-( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/kmenu.png kmenu.png )
-( cd opt/kde/share/doc/HTML/de/common ; rm -rf footer.html )
-( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/footer.html footer.html )
-( cd opt/kde/share/doc/HTML/de/common ; rm -rf kde-common.css )
-( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
-( cd opt/kde/share/doc/HTML/de/common ; rm -rf bottom-left.png )
-( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/bottom-left.png bottom-left.png )
-( cd opt/kde/share/doc/HTML/de/common ; rm -rf appheader.html )
-( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/appheader.html appheader.html )
-( cd opt/kde/share/doc/HTML/de/common ; rm -rf doctop1.png )
-( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/doctop1.png doctop1.png )
-( cd opt/kde/share/doc/HTML/de/common ; rm -rf doctop2.png )
-( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/doctop2.png doctop2.png )
-( cd opt/kde/share/doc/HTML/de/common ; rm -rf shadow.png )
-( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/shadow.png shadow.png )
-( cd opt/kde/share/doc/HTML/de/common ; rm -rf kde_logo.png )
-( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/kde_logo.png kde_logo.png )
-( cd opt/kde/share/doc/HTML/de/common ; rm -rf docheadergears.png )
-( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
-( cd opt/kde/share/doc/HTML/de/common ; rm -rf top-middle.png )
-( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/top-middle.png top-middle.png )
-( cd opt/kde/share/doc/HTML/de/common ; rm -rf fdl-license.html )
-( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/fdl-license.html fdl-license.html )
-( cd opt/kde/share/doc/HTML/de/common ; rm -rf bottom-right.png )
-( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/bottom-right.png bottom-right.png )
-( cd opt/kde/share/doc/HTML/de/common ; rm -rf doctop1a.png )
-( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/doctop1a.png doctop1a.png )
-( cd opt/kde/share/doc/HTML/de/common ; rm -rf 10.png )
-( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/10.png 10.png )
-( cd opt/kde/share/doc/HTML/de/common ; rm -rf doctop1b.png )
-( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/doctop1b.png doctop1b.png )
-( cd opt/kde/share/doc/HTML/de/common ; rm -rf lgpl-license )
-( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/lgpl-license lgpl-license )
-( cd opt/kde/share/doc/HTML/de/common ; rm -rf mainfooter.html )
-( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/mainfooter.html mainfooter.html )
-( cd opt/kde/share/doc/HTML/de/common ; rm -rf bottom1.png )
-( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/bottom1.png bottom1.png )
-( cd opt/kde/share/doc/HTML/de/common ; rm -rf bottom2.png )
-( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/bottom2.png bottom2.png )
-( cd opt/kde/share/doc/HTML/de/common ; rm -rf header.html )
-( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/header.html header.html )
-( cd opt/kde/share/doc/HTML/de/common ; rm -rf bottom-middle.png )
-( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/bottom-middle.png bottom-middle.png )
-( cd opt/kde/share/doc/HTML/de/common ; rm -rf top-left.png )
-( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/top-left.png top-left.png )
-( cd opt/kde/share/doc/HTML/de/common ; rm -rf gpl-license )
-( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/gpl-license gpl-license )
-( cd opt/kde/share/doc/HTML/de/common ; rm -rf kde-localised.css.template )
-( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/kde-localised.css.template kde-localised.css.template )
-( cd opt/kde/share/doc/HTML/de/common ; rm -rf bsd-license.html )
-( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/bsd-license.html bsd-license.html )
-( cd opt/kde/share/doc/HTML/de/common ; rm -rf web-docbottom.png )
-( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/web-docbottom.png web-docbottom.png )
-( cd opt/kde/share/doc/HTML/de/common ; rm -rf artistic-license.html )
-( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/artistic-license.html artistic-license.html )
 ( cd opt/kde/share/doc/HTML/de/kcontrol/kdm ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kcontrol/kdm ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kcontrol/smb ; rm -rf common )
@@ -312,8 +222,6 @@
 ( cd opt/kde/share/doc/HTML/de/kcontrol/keys ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kcontrol/powerctrl ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kcontrol/powerctrl ; ln -sf /opt/kde/share/doc/HTML/de/common common )
-( cd opt/kde/share/doc/HTML/de/kcontrol/kalarmd ; rm -rf common )
-( cd opt/kde/share/doc/HTML/de/kcontrol/kalarmd ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kcontrol/cookies ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kcontrol/cookies ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kcontrol/filetypes ; rm -rf common )
@@ -340,8 +248,6 @@
 ( cd opt/kde/share/doc/HTML/de/kcontrol/panel ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kcontrol/proxy ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kcontrol/proxy ; ln -sf /opt/kde/share/doc/HTML/de/common common )
-( cd opt/kde/share/doc/HTML/de/kcontrol/kmixcfg ; rm -rf common )
-( cd opt/kde/share/doc/HTML/de/kcontrol/kmixcfg ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kcontrol/desktopbehavior ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kcontrol/desktopbehavior ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kcontrol/lanbrowser ; rm -rf common )
@@ -376,8 +282,6 @@
 ( cd opt/kde/share/doc/HTML/de/kcontrol/kcmcss ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kcontrol/laptop ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kcontrol/laptop ; ln -sf /opt/kde/share/doc/HTML/de/common common )
-( cd opt/kde/share/doc/HTML/de/kcontrol/kxmlrpcd ; rm -rf common )
-( cd opt/kde/share/doc/HTML/de/kcontrol/kxmlrpcd ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kcontrol/kcmnotify ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kcontrol/kcmnotify ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kcontrol/kcmsmserver ; rm -rf common )
@@ -406,6 +310,8 @@
 ( cd opt/kde/share/doc/HTML/de/kcontrol/kcmtaskbar ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kcontrol/kcmfontinst ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kcontrol/kcmfontinst ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/kcontrol/performance ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/kcontrol/performance ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/artsbuilder ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/artsbuilder ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kicker-applets ; rm -rf common )
@@ -452,8 +358,6 @@
 ( cd opt/kde/share/doc/HTML/de/keduca ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kgamma ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kgamma ; ln -sf /opt/kde/share/doc/HTML/de/common common )
-( cd opt/kde/share/doc/HTML/de/kmessedwords ; rm -rf common )
-( cd opt/kde/share/doc/HTML/de/kmessedwords ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kicker ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kicker ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/klatin ; rm -rf common )
@@ -470,8 +374,6 @@
 ( cd opt/kde/share/doc/HTML/de/knotes ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kpager ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kpager ; ln -sf /opt/kde/share/doc/HTML/de/common common )
-( cd opt/kde/share/doc/HTML/de/kpaint ; rm -rf common )
-( cd opt/kde/share/doc/HTML/de/kpaint ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kopete ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kopete ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kpilot ; rm -rf common )
@@ -498,18 +400,26 @@
 ( cd opt/kde/share/doc/HTML/de/kreversi ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/noatun ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/noatun ; ln -sf /opt/kde/share/doc/HTML/de/common common )
-( cd opt/kde/share/doc/HTML/de/opengl ; rm -rf common )
-( cd opt/kde/share/doc/HTML/de/opengl ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/ksplashml ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/ksplashml ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kdebugdialog ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kdebugdialog ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kblackbox ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kblackbox ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kcharselect ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kcharselect ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/quanta ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/quanta ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/superkaramba ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/superkaramba ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/ksmiletris ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/ksmiletris ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kuickshow ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kuickshow ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kolourpaint ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kolourpaint ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/kommander ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/kommander ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kiconedit ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kiconedit ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kmahjongg ; rm -rf common )
@@ -522,6 +432,8 @@
 ( cd opt/kde/share/doc/HTML/de/kghostview ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/klickety ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/klickety ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/kfilereplace ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/kfilereplace ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kpovmodeler ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kpovmodeler ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kleopatra ; rm -rf common )
@@ -534,14 +446,14 @@
 ( cd opt/kde/share/doc/HTML/de/kwatchgnupg ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kworldclock ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kworldclock ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/blinken ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/blinken ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/KRegExpEditor ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/KRegExpEditor ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/ksokoban ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/ksokoban ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kteatime ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kteatime ; ln -sf /opt/kde/share/doc/HTML/de/common common )
-( cd opt/kde/share/doc/HTML/de/kmathtool ; rm -rf common )
-( cd opt/kde/share/doc/HTML/de/kmathtool ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kinfocenter/dma ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kinfocenter/dma ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kinfocenter/pci ; rm -rf common )
@@ -566,12 +478,16 @@
 ( cd opt/kde/share/doc/HTML/de/kinfocenter/sound ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kinfocenter/partitions ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kinfocenter/partitions ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/kinfocenter/cdinfo ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/kinfocenter/cdinfo ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kinfocenter ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kinfocenter ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kinfocenter/memory ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kinfocenter/memory ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kinfocenter/pcmcia ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kinfocenter/pcmcia ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/kinfocenter/opengl ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/kinfocenter/opengl ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kinfocenter/processor ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kinfocenter/processor ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kinfocenter/ioports ; rm -rf common )
@@ -590,5 +506,3 @@
 ( cd opt/kde/share/doc/HTML/de/korganizer ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/atlantik ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/atlantik ; ln -sf /opt/kde/share/doc/HTML/de/common common )
-( cd opt/kde/share/doc/HTML/de/visualdict ; rm -rf common )
-( cd opt/kde/share/doc/HTML/de/visualdict ; ln -sf /opt/kde/share/doc/HTML/de/common common )
